@@ -31,7 +31,7 @@ use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 use Image::ExifTool::Exif;
 
-$VERSION = '1.95';
+$VERSION = '1.98';
 
 sub ProcessFujiDir($$$);
 sub ProcessFaceRec($$$);
@@ -628,6 +628,10 @@ my %faceCategories = (
             0x60006 => 'Partial Color Purple',
             0x70000 => 'Soft Focus',
             0x90000 => 'Low Key',
+            0x100000 => 'Light Leak', #forum17392
+            0x130000 => 'Expired Film Green', #forum17392
+            0x130001 => 'Expired Film Red', #forum17392 (NC)
+            0x130002 => 'Expired Film Neutral', #forum17392
         },
     },
     0x1210 => { #2
@@ -828,6 +832,13 @@ my %faceCategories = (
     },
     0x1447 => { Name => 'FujiModel',  Writable => 'string' },
     0x1448 => { Name => 'FujiModel2', Writable => 'string' },
+
+    # Found in X-M5, X-E5
+    # White balance as shot. Same valus as 0xf00e.
+    0x144a => { Name => 'WBRed',      Writable => 'int16u' },
+    0x144b => { Name => 'WBGreen',    Writable => 'int16u' },
+    0x144c => { Name => 'WBBlue',     Writable => 'int16u' },
+    
     0x144d => { Name => 'RollAngle',  Writable => 'rational64s' }, #forum14319
     0x3803 => { #forum10037
         Name => 'VideoRecordingMode',
@@ -1196,7 +1207,7 @@ my %faceCategories = (
         Name => 'RAFCompression',
         Condition => '$$valPt =~ /^\0\0\0/', # (JPEG header is in this location for some RAF versions)
         Format => 'int32u',
-        PrintConv => { 0 => 'None', 2 => 'Lossless', 3 => 'Lossy'  },
+        PrintConv => { 0 => 'Uncompressed', 2 => 'Lossless', 3 => 'Lossy'  },
     },
   # 0x70 - ? same as 0x68?
   # 0x74 - ? usually 0, but have seen 0x1700
@@ -1252,6 +1263,28 @@ my %faceCategories = (
         ValueConv => 'my @v=reverse split(" ",$val);"@v"', # reverse to show width first
         PrintConv => '$val=~tr/ /:/; $val',
     },
+    0x117 => {
+        Name => 'RawZoomActive',
+        Format => 'int32u',
+        Count => 1,
+        PrintConv => { 0 => 'No', 1 => 'Yes' },
+    },
+    0x118 => {
+        Name => 'RawZoomTopLeft',
+        Format => 'int16u',
+        Count => 2,
+        Notes => 'relative to RawCroppedImageSize',
+        ValueConv => 'my @v=reverse split(" ",$val);"@v"', # reverse to show width first
+        PrintConv => '$val=~tr/ /x/; $val',
+    },
+    0x119 => {
+        Name => 'RawZoomSize',
+        Format => 'int16u',
+        Count => 2,
+        Notes => 'relative to RawCroppedImageSize',
+        ValueConv => 'my @v=reverse split(" ",$val);"@v"', # reverse to show width first
+        PrintConv => '$val=~tr/ /x/; $val',
+    },
     0x121 => [
         {
             Name => 'RawImageSize',
@@ -1538,7 +1571,7 @@ my %faceCategories = (
     6 => { Name => 'FNumber', Format => 'rational64u', PrintConv => 'Image::ExifTool::Exif::PrintFNumber($val)' },
     # 7 - seen 200, 125, 250, 2000
     7 => 'ISO',
-    # 8 - seen 0
+    # 8 - seen 0, 65536
 );
 
 #------------------------------------------------------------------------------
@@ -1647,7 +1680,7 @@ sub ProcessFujiDir($$$)
 #------------------------------------------------------------------------------
 # get information from FujiFilm M-RAW header
 # Inputs: 0) ExifTool ref, 1) dirInfo ref, 2) tag table ref
-# Returns: 1 if this was a valid M-RAW headerx
+# Returns: 1 if this was a valid M-RAW header
 sub ProcessMRAW($$$)
 {
     my ($et, $dirInfo, $tagTablePtr) = @_;
@@ -1783,6 +1816,7 @@ sub WriteRAF($$)
         # make sure padding is only zero bytes (can be >100k for HS10)
         # (have seen non-null padding in X-Pro1)
         if ($buff =~ /[^\0]/) {
+HexDump(\$buff);
             return 1 if $et->Error('Non-null bytes found in padding', 2);
         }
     }
@@ -1937,7 +1971,7 @@ FujiFilm maker notes in EXIF information, and to read/write FujiFilm RAW
 
 =head1 AUTHOR
 
-Copyright 2003-2024, Phil Harvey (philharvey66 at gmail.com)
+Copyright 2003-2025, Phil Harvey (philharvey66 at gmail.com)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
